@@ -110,9 +110,9 @@ class Project():
 
     def build_virtualenv(self):
         """build the virtual environment for this backstage project"""
-        venvdir = os.path.join(self.PROJECT_ROOT,'project/virtualenv')
+        venvdir = os.path.join(self.PROJECT_ROOT,'venv')
         cmd = '%s/build_virtualenv' % (venvdir)
-        os.system('virtualenv --no-site-packages %s' % venvdir)
+        subprocess.call(cmd)
         execfile(os.path.join(venvdir,'bin/activate_this.py'))
         return
 
@@ -133,8 +133,6 @@ def copy_project_skel(project_path):
         raise
     return True
 
-
-
 def new_project(project_name, project_path, source_ini_file = None):
         """create a new backstage project with the given name and located at the specified path"""
         project_path = os.path.abspath(os.path.join(project_path, project_name))
